@@ -3,7 +3,8 @@ import logging
 import socket
 import time
 from msmart.security import security, MSGTYPE_HANDSHAKE_REQUEST, MSGTYPE_ENCRYPTED_REQUEST
-VERSION = '0.1.30'
+
+VERSION = '0.1.31'
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -56,7 +57,7 @@ class lan:
             if self._socket is None:
                 _LOGGER.error("Sokcet is None: {}:{}".format(
                     self.device_ip, self.device_port))
-                return bytearray(0)
+                return bytearray(0), False
             _LOGGER.debug("Socket {} -> {} tcp_key: {}".format(
                 self._local, self._remote, self._tcp_key))
             # Send data
@@ -75,12 +76,12 @@ class lan:
             else:
                 _LOGGER.error("Couldn't connect with Device {}:{} retries: {} error: {}".format(
                     self.device_ip, self.device_port, self._retries, error))
-            return bytearray(0)
+            return bytearray(0), True
         except socket.timeout:
             _LOGGER.error("Connect the Device {}:{} TimeOut for 8s. don't care about a small amount of this. if many maybe not support".format(
                 self.device_ip, self.device_port))
             self._disconnect()
-            return bytearray(0)
+            return bytearray(0), True
         _LOGGER.debug("Received from {}:{} {}".format(
             self.device_ip, self.device_port, response.hex()))
         if response == bytearray(0):
@@ -88,7 +89,7 @@ class lan:
                     self.device_ip, self.device_port))
             self._disconnect()
             self._retries += 1
-        return response
+        return response, True
 
     def authenticate(self, token: bytearray, key: bytearray):
         self._token, self._key = token, key
@@ -96,17 +97,18 @@ class lan:
             raise Exception('missing token key pair')
         request = self.security.encode_8370(
             self._token, MSGTYPE_HANDSHAKE_REQUEST)
-        response = self.request(request)[8:72]
-        try:
-            tcp_key = self.security.tcp_key(response, self._key)
+        response, _ = self.request(request)
+        response = response[8:72]
+
+        tcp_key, success = self.security.tcp_key(response, self._key)
+        if success:
             self._tcp_key = tcp_key.hex()
             _LOGGER.info('Got TCP key for {}:{} {}'.format(
-                self.device_ip, self.device_port, tcp_key.hex()))
+            self.device_ip, self.device_port, tcp_key.hex()))
             # After authentication, don’t send data immediately, so sleep 1s.
             time.sleep(1)
-        except Exception as error:
-            self._disconnect()
-            raise error
+        return success
+
 
     def _authenticate(self):
         if not self._token or not self._key:
@@ -124,11 +126,11 @@ class lan:
         # copy from data in order to resend data
         original_data = bytearray.copy(data)
         data = self.security.encode_8370(data, msgtype)
-        # time sleep retries second befor send data, default is 0 
+        # time sleep retries second befor send data, default is 0
         time.sleep(self._retries)
-        responses = self.request(data)
+        responses, b = self.request(data)
         _LOGGER.debug("Got responses len: {}".format(len(responses)))
-        if responses == bytearray(0) and self._retries < 2:
+        if responses == bytearray(0) and self._retries < 2 and b:
             packets = self.appliance_transparent_send_8370(original_data, msgtype)
             self._retries = 0
             return packets
@@ -142,16 +144,17 @@ class lan:
         return packets
 
     def appliance_transparent_send(self, data):
-        # time sleep retries second befor send data, default is 0 
+        # time sleep retries second befor send data, default is 0
         time.sleep(self._retries)
-        responses = self.request(data)
+        responses, b = self.request(data)
         _LOGGER.debug("Got responses len: {}".format(len(responses)))
-        if responses == bytearray(0) and self._retries < 2:
-            return self.appliance_transparent_send(data)
-        self._retries = 0
-        if responses == bytearray(0):
-            return responses
+        if responses == bytearray(0) and self._retries < 2 and b:
+            packets = self.appliance_transparent_send(data)
+            self._retries = 0
+            return packets
         packets = []
+        if responses == bytearray(0):
+            return packets
         if responses[:2].hex() == "5a5a":
             # maybe multiple response
             for response in responses.split(bytearray.fromhex('5a5a')):
